@@ -261,21 +261,29 @@ function setUpTree() {
 /* Turn all objects with class "popup-trigger" into jquery overlay triggers. */
 function setUpOverlays() {
     $(".popup-trigger").each(function () {
-        $(this).overlay();
+        $(this).overlay({
+            onLoad: function (event) {
+                var first_field;
+                first_field = $("input:visible:enabled:first", this.getOverlay()).get(0);
+                if (first_field) {
+                    first_field.focus();
+                }
+            }
+        });
     });
 }
 
 /* Make the "login" button post the login request and react on response */
 function setUpLogin() {
-    $("#login-button").click(function () {
+    $("#popup-login-form").submit(function () {
         var url, $form;
-        $form = $(this).parents("form");
+        $form = $(this);
         url = $form.attr("data-url");
         $.post(
             url,
             $form.serialize(),
             function (data) {
-                if (data == "true") {
+                if (data === "true") {
                     // Login successful.
                     window.location.reload();
                 } else {
@@ -284,6 +292,7 @@ function setUpLogin() {
                     $("#wrong-login").overlay({load: true });
                 }
             });
+        return false;  // Prevents propagation to original form submit.
     });
     $("#logout-button").click(function () {
         var url;
